@@ -10,7 +10,8 @@ from selenium.webdriver.common.keys import Keys
 from lazyTest.base.config import Config
 from selenium.webdriver.support.select import Select
 from selenium.webdriver.common.action_chains import ActionChains
-from lazyTest.base.utils import _retrying,Retrying
+from lazyTest.base.utils import _retrying,Retrying,lazyLog
+from selenium.common.exceptions import TimeoutException,NoSuchElementException
 
 
 class WebOption(Config):
@@ -19,6 +20,7 @@ class WebOption(Config):
         lazyTest.logger.debug(f"WebOption.Get: {urls}")
         self.baseDriver.get(urls)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def Click(self, selector: str) -> None:
@@ -27,6 +29,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         ele.click()
 
+    @lazyLog
     @Retrying()
     @_retrying
     def RightClick(self, selector: str) -> None:
@@ -35,6 +38,7 @@ class WebOption(Config):
         self.locate_element(selector)
         ActionChains(self.baseDriver).context_click(selector)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def DoubleClick(self, selector: str) -> None:
@@ -50,15 +54,16 @@ class WebOption(Config):
         end = self.locate_element(target)
         ActionChains(self.baseDriver).drag_and_drop(start, end)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def ActionScroll(self, selector: str, x: int = 0, y: int = 10):
-        lazyTest.logger.debug(f"WebOption.ActionScroll {selector}")
         """内嵌滚动条滚动"""
+        lazyTest.logger.debug(f"WebOption.ActionScroll {selector}")
         ele = self.locate_element(selector)
         ActionChains(self.baseDriver).drag_and_drop_by_offset(ele, x, y).perform()
 
-    
+    @lazyLog
     @Retrying()
     @_retrying
     def Input(self, selector: str, *value: str) -> None:
@@ -67,6 +72,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         ele.send_keys(*value)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def Clear(self, selector: str) -> None:
@@ -75,6 +81,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         ele.clear()
 
+    @lazyLog
     @Retrying()
     @_retrying
     def KeysClear(self, selector: str):
@@ -84,6 +91,7 @@ class WebOption(Config):
         ele.send_keys(Keys.CONTROL, "a")
         ele.send_keys(Keys.DELETE)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def ClearAndInput(self, selector: str, value: str) -> None:
@@ -93,6 +101,7 @@ class WebOption(Config):
         ele.clear()
         ele.send_keys(value)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def GetText(self, selector: str) -> str:
@@ -101,6 +110,7 @@ class WebOption(Config):
         lazyTest.logger.debug(f"WebOption.GetText {selector} --->{ele.text}")
         return ele.text
 
+    @lazyLog
     @Retrying()
     @_retrying
     def GetTexts(self, selector: str, index: int = None) -> list:
@@ -114,6 +124,7 @@ class WebOption(Config):
             lazyTest.logger.debug(f"WebOption.GetTexts {selector}  --->{text_list}")
             return text_list
 
+    @lazyLog
     @Retrying()
     @_retrying
     def GetElement(self, selector: str):
@@ -122,6 +133,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         return ele
 
+    @lazyLog
     @Retrying()
     @_retrying
     def GetElements(self, selector: str, text: str = "", index: int = None, ):
@@ -138,6 +150,7 @@ class WebOption(Config):
             return eles
         return ele
 
+    @lazyLog
     @Retrying()
     @_retrying
     def ElementFilterByText(self, selector: str, text: str):
@@ -149,7 +162,9 @@ class WebOption(Config):
             for i in ele:
                 if i.text == text:
                     return i
+        raise NoSuchElementException
 
+    @lazyLog
     @Retrying()
     @_retrying
     def ElementFilterByIndex(self, selector: str, index: int = None):
@@ -158,6 +173,7 @@ class WebOption(Config):
         ele = self.locate_elements(selector)
         return ele[index]
 
+    @lazyLog
     @Retrying()
     @_retrying
     def GetAttribute(self, selector: str, value: str = 'value') -> str:
@@ -169,6 +185,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         return ele.get_attribute(value)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def AddAttribute(self, selector: str, attributeName: str, value: str):
@@ -178,6 +195,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         self.baseDriver.execute_script("arguments[0].%s=arguments[1]" % attributeName, ele, value)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def SetAttribute(self, selector: str, attributeName: str, value: str):
@@ -188,6 +206,7 @@ class WebOption(Config):
         self.baseDriver.execute_script("arguments[0].setAttribute(arguments[1],arguments[2])", ele, attributeName,
                                        value)
 
+    @lazyLog
     @Retrying()
     @_retrying
     def SwitchFrame(self, selector: str) -> None:
@@ -216,6 +235,7 @@ class WebOption(Config):
         elif operation == 'dismiss':
             alert.dismiss()
 
+    @lazyLog
     @Retrying()
     @_retrying
     def SelectOperation(self, selector: str, operation_type: str, value: str) -> None:
@@ -262,6 +282,7 @@ class WebOption(Config):
             get_js = f"window.scrollBy(0,{i});"  # 执行多个js脚本则需要用到scrollBy；表示再次下拉到300位置
             self.baseDriver.execute_script(get_js)  # 执行js脚本
 
+    @lazyLog
     @Retrying()
     @_retrying
     def getALlPageText(self, selector: str) -> list:
