@@ -72,12 +72,12 @@ class Config:
         :param s: 休眠时间，单位：秒
         :return:
         """
-        lazyTest.logger.debug(f"隐式等待生效：{s} s")
+        lazyTest.logger.success(f"implicitly_wait：{s} s")
         self.baseDriver.implicitly_wait(s)
 
     def webdriver_wait(self, selector: str) -> None:
         """显示等待元素"""
-        lazyTest.logger.debug(f"显示等待生效：等待：10 s，每 0.5 s 刷新")
+        lazyTest.logger.success(f"webdriver_wait  presence_of_element_located")
         locator = self.__locate_Element_selector(selector)
         WebDriverWait(self.baseDriver, 10, 0.5).until(
             EC.presence_of_element_located(locator))
@@ -89,8 +89,8 @@ class Config:
         :return: 返回定位方式
         """
         selector_by = selector.split(',')[0].strip()
-        selector_value = selector.split(',')[1].strip()
-        lazyTest.logger.debug(f"定位元素:({locator[selector_by]},{selector_value})")
+        selector_value = selector.split(',',1)[1].strip()
+        lazyTest.logger.success(f"__locate_Element_selector:{locator[selector_by]},{selector_value}")
         selector_value = OPtionElements(selector_by, selector_value)
         return locator[selector_by], selector_value
 
@@ -101,9 +101,26 @@ class Config:
         :return: 返回定位元素对象
         """
         self.webdriver_wait(selector)
-        locator = self.__locate_Element_selector(selector)
-        element = self.baseDriver.find_element(*locator)
-        return element
+        if selector.find(":") == -1:
+            locator = self.__locate_Element_selector(selector)
+            element = self.baseDriver.find_element(*locator)
+            return element
+        else:
+            start = selector.split(":")[0]
+            condition = selector.split(":")[1]
+            locator = self.__locate_Element_selector(start)
+            elements = self.baseDriver.find_elements(*locator)
+            try:
+               i =  int(condition)
+               return elements[i]
+            except ValueError as e:
+                lazyTest.logger.debug(f"condition valueError {e}")
+                for ele in elements:
+                    if ele.text == condition:
+                        return ele
+                else:
+                    return elements[0]
+
 
     def locate_elements(self, selector: str) -> list:
         """
