@@ -11,25 +11,27 @@ import lazyTest
 def _retrying(func):
     @functools.wraps(func)
     def inner(*args):
-        lazyTest.logger.debug(f"传入的selector为：{args[1]}")
+        lazyTest.logger.debug(f"receive element selector : {args[1]}")
         if isinstance(args[1], str):
-            lazyTest.logger.debug("字符串不进行重试")
+            lazyTest.logger.debug(f"{args[1]} type is str not retry")
             result = func(*args)
             return result
+        lazyTest.logger.debug(f"type is list init retry config {args[1]}")
         ele = iter(args[1])
-
         def run(ele, *args):
             args = list(args)  # 兼容多个参数
             try:
                 e = next(ele)
-                lazyTest.logger.debug(f"元素重试机制-->尝试定位：{e}")
+                lazyTest.logger.debug(f"attempt location {e}")
             except StopIteration:
-                raise Exception(f"元素重试结束，无法定位：{args}")
+                lazyTest.logger.error(f"locate retry failed")
+                raise Exception(f"element retry close can not locate: {args}")
             try:
                 args[1] = e  # 处理时只处理第一个参数
                 result = func(*args)
                 return result
-            except BaseException as e:  # 捕获所有异常
+            except BaseException:  # 捕获所有异常
+                lazyTest.logger.debug("----------------------------- element next -----------------------------")
                 result = run(ele, *args)
             return result
 
@@ -52,17 +54,20 @@ def Retrying(num: int = 2):
         @functools.wraps(func)
         def inner(*args, **kwargs):
             nonlocal num
-            lazyTest.logger.debug(f"动作重试机制生效，总重试次数：{num}")
+            lazyTest.logger.debug(f"action retry init retry num :{num}")
 
             @lazyTest.Sleep(1)
             def run(num, *args, **kwargs):
+                lazyTest.logger.debug(f"action retry this is :{num} num")
                 try:
                     result = func(*args, **kwargs)
                     return result
                 except BaseException:
                     if num == 0:
-                        raise Exception("动作重试结束，无法完成指定动作")
-                    lazyTest.logger.error(f"动作执行失败，重试")
+                        lazyTest.logger.error(f"action retry failed ")
+                        lazyTest.logger.debug("-----------------------------  end  -----------------------------")
+                        raise Exception("action retry close can not locate")
+                    lazyTest.logger.debug("----------------------------- action next -----------------------------")
                     num -= 1
                     run(num, *args, **kwargs)
 
@@ -72,3 +77,12 @@ def Retrying(num: int = 2):
         return inner
 
     return retrying
+
+def lazyLog(func):
+    @functools.wraps(func)
+    def inner(*args,**kwargs):
+        lazyTest.logger.debug("----------------------------- ready -----------------------------")
+        result = func(*args,**kwargs)
+        lazyTest.logger.debug("---------------------------  success  ---------------------------")
+        return result
+    return inner
\ No newline at end of file
