@@ -5,7 +5,6 @@
 # Describe :
 # ---------------------------------------
 
-import logging
 import warnings
 
 import lazyTest
@@ -18,7 +17,8 @@ class Page(object):
 
     def __init__(self, driver: lazyTest.WebOption):
         self.driver = driver
-        self.lazyLog = logging.getLogger(self.getClassName())
+        # self.lazyLog = logging.getLogger(self.getClassName())
+        self.lazyLog = lazyTest.logger
         self.config = lazyTest.ReadIni(self.GetProjectPath() + self.__configFile)
         path = self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
         self.lazyLog.info("元素文件: -> %s" % path)
